@@ -1,4 +1,5 @@
 import types
+import warnings
 from typing import Type
 
 import attr
@@ -10,6 +11,8 @@ from .constructor import converter
 from .logging import Logging
 from .requests import PreparedRequestHook, RequestHook, ResponseHook
 
+warnings.warn("Please use apitist (https://pypi.org/project/apitist) package now", DeprecationWarning)
+
 
 class RequestDebugLoggingHook(RequestHook):
     formatter = "Request {req.method} {req.url} {req.data}"
