@@ -1,5 +1,6 @@
 import inspect
 import typing
+import warnings
 
 import attr
 
@@ -9,6 +10,8 @@ from .logging import Logging
 
 T = typing.TypeVar("T")
 
+warnings.warn("Please use apitist (https://pypi.org/project/apitist) package now", DeprecationWarning)
+
 
 class Randomer:
     _types_dict = None
